]> git.ipfire.org Git - thirdparty/binutils-gdb.git/commitdiff
* ChangeLog: Fix typos.
authorKazu Hirata <kazu@codesourcery.com>
Mon, 27 Oct 2003 12:45:17 +0000 (12:45 +0000)
committerKazu Hirata <kazu@codesourcery.com>
Mon, 27 Oct 2003 12:45:17 +0000 (12:45 +0000)
* ChangeLog-9295: Likewise.
* as.c: Fix comment typos.
* as.h: Likewise.
* atof-generic.c: Likewise.
* bit_fix.h: Likewise.
* frags.h: Likewise.
* hash.c: Likewise.
* input-file.c: Likewise.
* input-scrub.c: Likewise.
* itbl-ops.c: Likewise.
* itbl-parse.y: Likewise.
* listing.c: Likewise.
* macro.h: Likewise.
* read.c: Likewise.
* sb.c: Likewise.
* sb.h: Likewise.
* symbols.c: Likewise.
* symbols.h: Likewise.

19 files changed:
gas/ChangeLog
gas/ChangeLog-9295
gas/as.c
gas/as.h
gas/atof-generic.c
gas/bit_fix.h
gas/frags.h
gas/hash.c
gas/input-file.c
gas/input-scrub.c
gas/itbl-ops.c
gas/itbl-parse.y
gas/listing.c
gas/macro.h
gas/read.c
gas/sb.c
gas/sb.h
gas/symbols.c
gas/symbols.h

index 291895d2add59344fab7c227ee4b63abcb55a3ed..85668d0d20c3ae12d04700de2de62509c105bbd5 100644 (file)
@@ -1,3 +1,25 @@
+2003-10-27  Kazu Hirata  <kazu@cs.umass.edu>
+
+       * ChangeLog: Fix typos.
+       * ChangeLog-9295: Likewise.
+       * as.c: Fix comment typos.
+       * as.h: Likewise.
+       * atof-generic.c: Likewise.
+       * bit_fix.h: Likewise.
+       * frags.h: Likewise.
+       * hash.c: Likewise.
+       * input-file.c: Likewise.
+       * input-scrub.c: Likewise.
+       * itbl-ops.c: Likewise.
+       * itbl-parse.y: Likewise.
+       * listing.c: Likewise.
+       * macro.h: Likewise.
+       * read.c: Likewise.
+       * sb.c: Likewise.
+       * sb.h: Likewise.
+       * symbols.c: Likewise.
+       * symbols.h: Likewise.
+
 2003-10-27  Stephane Carrez  <stcarrez@nerim.fr>
 
        * config/tc-m68hc11.c: Convert to ISO C90.
        operands.
        (OPTION_MIPS32R2): New define.
        (md_longopts): Add entry for OPTION_MIPS32R2.
-       (OPTION_ELF_BASE): Adjust to accomodate OPTIONS_MIPS32R2.
+       (OPTION_ELF_BASE): Adjust to accommodate OPTIONS_MIPS32R2.
        (md_parse_option): Handle OPTION_MIPS32R2.
        (s_mipsset): Reimplement handling of ".set mipsN" options
        and add support for ".set mips32r2".
@@ -4999,7 +5021,7 @@ Thu Oct 10 14:31:30 2002  J"orn Rennecke <joern.rennecke@superh.com>
        types.
        (OPTION_MDMX, OPTION_NO_MDMX, md_longopts, md_parse_option):
        Add support for "-mdmx" and "-no-mdmx" options.
-       (OPTION_ELF_BASE): Move to accomodate new options.
+       (OPTION_ELF_BASE): Move to accommodate new options.
        (s_mipsset): Support ".set mdmx" and ".set nomdmx".
        (mips_elf_final_processing): Set MDMX ASE ELF header flag if
        file_ase_mdmx was set.
@@ -5638,7 +5660,7 @@ Thu Oct 10 14:31:30 2002  J"orn Rennecke <joern.rennecke@superh.com>
        mips_opts.ase_mips3d is set.
        (OPTION_MIPS3D, OPTION_NO_MIPS3D, md_longopts, md_parse_option):
        Add support for "-mips3d" and "-no-mips3d" options.
-       (OPTION_ELF_BASE): Move to accomodate new options.
+       (OPTION_ELF_BASE): Move to accommodate new options.
        (s_mipsset): Support ".set mips3d" and ".set nomips3d".
        (mips_elf_final_processing): Add a comment indicating that a
        MIPS-3D ASE ELF header flag should be set, when one exists.
index 17407e5db7af0c9af96b2d02aa6e03bea6c8304e..71357330152801844e885645e56b145b7285684f 100644 (file)
@@ -9003,7 +9003,7 @@ Thu Oct 14 16:51:00 1993  Ian Lance Taylor  (ian@tweedledumb.cygnus.com)
        * app.c (do_scrub_next_char): Always accept 'x' and 'X' as escape
        characters in state 6.
        * read.c (next_char_of_string): Accept \Xh* and \xh* where h* are
-       hexidecimal digits.
+       hexadecimal digits.
 
        * config/tc-i386.c (md_apply_fix_1): Make cross segment calls work
        for ELF by hacking around bizarre bfd_perform_relocation behaviour
@@ -13007,7 +13007,7 @@ Sat Feb 22 12:26:28 1992  Steve Chamberlain  (sac at rtl.cygnus.com)
        * app.c: MRI compatibility - allow single quote to start a string.
        * as.c: fix typo recently introduced.
        * as.h : Don't include aout/reloc.h - it's not right for COFF!
-       * expr.c: Much rewriting, to accomodate MRI syntax for
+       * expr.c: Much rewriting, to accommodate MRI syntax for
        expressions. Also easier to read now.
        * listing.c: Put back defuns
        * read.c: modified to accept MRI syntax, put back listing pseudo
index 20d1522dbca8a599410458f76ff7cc348f19b9b2..0911aa1fa2605502669139de72caa16bf8908a2f 100644 (file)
--- a/gas/as.c
+++ b/gas/as.c
@@ -501,7 +501,7 @@ parse_args (int * pargc, char *** pargv)
          if (md_parse_option (optc, optarg) != 0)
            break;
          /* `-v' isn't included in the general short_opts list, so check for
-            it explicity here before deciding we've gotten a bad argument.  */
+            it explicitly here before deciding we've gotten a bad argument.  */
          if (optc == 'v')
            {
 #ifdef VMS
index 28806d53e202fb505415ee95af314ddc973a5f88..f8b8d1d2bd7941f9ea86c3e44377cdd267d74d14 100644 (file)
--- a/gas/sb.c
+++ b/gas/sb.c
@@ -265,7 +265,7 @@ sb_skip_white (idx, ptr)
 }
 
 /* start at the index idx into the sb at ptr. skips whitespace,
-   a comma and any following whitespace. returnes the index of the
+   a comma and any following whitespace. returns the index of the
    next character.  */
 
 int
index dd01e0ddb75ffc3d0fe31da23103c279f3a6368a..d3e160d8021c426a228f5737862395c4073eb87f 100644 (file)
--- a/gas/sb.h
+++ b/gas/sb.h
@@ -44,7 +44,7 @@
    Obstacks provide all the functionality needed, but are too
    complicated, hence the sb.
 
-   An sb is allocated by the caller, and is initialzed to point to an
+   An sb is allocated by the caller, and is initialized to point to an
    sb_element.  sb_elements are kept on a free lists, and used when
    needed, replaced onto the free list when unused.
  */
index 7362afbbaf4c347faa7cded247a940d91322b77a..02cd867fc777b40357c63fda53732f477bd23dc9 100644 (file)
@@ -1464,7 +1464,7 @@ dollar_label_name (n, augend)
   return symbol_name_build;
 }
 
-/* Sombody else's idea of local labels. They are made by "n:" where n
+/* Somebody else's idea of local labels. They are made by "n:" where n
    is any decimal digit. Refer to them with
     "nb" for previous (backward) n:
    or "nf" for next (forward) n:.
index 0bc88d8b41256ce6504dabbac4d0ef67e847c241..71065671e3991d3a876123934c981b46091d2730 100644 (file)
@@ -131,7 +131,7 @@ struct broken_word
     symbolS *sub;
     offsetT addnum;
 
-    int added;                 /* nasty thing happend yet? */
+    int added;                 /* nasty thing happened yet? */
     /* 1: added and has a long-jump */
     /* 2: added but uses someone elses long-jump */
--- a/gas/as.h
+++ b/gas/as.h
@@ -237,7 +237,7 @@ typedef addressT valueT;
 #ifdef TEST
 #define COMMON                 /* declare our COMMONs storage here.  */
 #else
-#define COMMON extern          /* our commons live elswhere */
+#define COMMON extern          /* our commons live elsewhere */
 #endif
 #endif
 /* COMMON now defined */
index c5d10d42051272bbcdbd3f6c1a7131630c9e2250..6b6c7b25e91e95f5b15380a558c4aa6bb41b7275 100644 (file)
@@ -472,7 +472,7 @@ atof_generic (address_of_string_pointer,
       {
        /*
         * Compute the mantssa (& exponent) of the power of 10.
-        * If sucessful, then multiply the power of 10 by the digits
+        * If successful, then multiply the power of 10 by the digits
         * giving return_binary_mantissa and return_binary_exponent.
         */
 
index 80c002278a6f033da540a960db0c6ceb3e2d010a..1676d2c5f0bde829bc09227f5b4e16e2928d16ec 100644 (file)
@@ -20,7 +20,7 @@
 
 /* The bit_fix was implemented to support machines that need variables
    to be inserted in bitfields other than 1, 2 and 4 bytes.
-   Furthermore it gives us a possibillity to mask in bits in the symbol
+   Furthermore it gives us a possibility to mask in bits in the symbol
    when it's fixed in the objectcode and check the symbols limits.
 
    The or-mask is used to set the huffman bits in displacements for the
index 9d52ae8357958c96193eef1d17a15f32a0502a51..82bf7c8ef09695840fbd1b215bbce3bc3c13773d 100644 (file)
@@ -116,7 +116,7 @@ COMMON fragS bss_address_frag;
 
 #if 0
 /* A macro to speed up appending exactly 1 char to current frag.  */
-/* JF changed < 1 to <= 1 to avoid a race conditon.  */
+/* JF changed < 1 to <= 1 to avoid a race condition.  */
 #define FRAG_APPEND_1_CHAR(datum)                      \
 {                                                      \
   if (obstack_room (&frags) <= 1)                      \
index df9101db6bec8cf83741cc06bd2ffb1cccf12c1d..2756f23f6c5184170025ae70122c26f7df8fd4fc 100644 (file)
@@ -430,7 +430,7 @@ char answer[100];
 /* We test many hash tables at once.  */
 char *hashtable[TABLES];
 
-/* Points to curent hash_control.  */
+/* Points to current hash_control.  */
 char *h;
 char **pp;
 char *p;
index 5c23f31eacfb9abe1bde8df60d21a4041e2f4ab9..b6c91ed5a52b66710344f7874099c215331523c3 100644 (file)
@@ -58,7 +58,7 @@ struct saved_file
     char * app_save;
   };
 \f
-/* These hooks accomodate most operating systems.  */
+/* These hooks accommodate most operating systems.  */
 
 void
 input_file_begin ()
index d3437114aa4277776cd5bd00c32d638f11d0b4f5..84beacaf728087c995674b0fffc60e9e78621982 100644 (file)
@@ -33,7 +33,7 @@
  * were broken across buffers, and return a buffer of full lines to
  * the caller.
  * The last partial line begins the next buffer we build and return to caller.
- * The buffer returned to caller is preceeded by BEFORE_STRING and followed
+ * The buffer returned to caller is preceded by BEFORE_STRING and followed
  * by AFTER_STRING, as sentinels. The last character before AFTER_STRING
  * is a newline.
  * Also looks after line numbers, for e.g. error messages.
index 09db9f74683f79cd87c692265d40f7a2de3123ad..2d1ae45559f6a65b7971518abe784d42a17d6c93 100644 (file)
@@ -351,7 +351,7 @@ append_insns_as_macros (void)
       printf (_("Unable to allocate memory for new instructions\n"));
       return;
     }
-  if (size)                    /* copy prexisting opcodes table */
+  if (size)                    /* copy preexisting opcodes table */
     memcpy (new_opcodes, ITBL_OPCODES, size);
 
   /* FIXME! some NUMOPCODES are calculated expressions.
@@ -372,13 +372,13 @@ append_insns_as_macros (void)
          o->name = e->name;
          o->args = strdup (form_args (e));
          o->mask = apply_range (e->value, e->range);
-         /* FIXME how to catch durring assembly? */
+         /* FIXME how to catch during assembly? */
          /* mask to identify this insn */
          o->match = apply_range (e->value, e->range);
          o->pinfo = 0;
 
 #ifdef USE_MACROS
-         o->mask = id++;       /* FIXME how to catch durring assembly? */
+         o->mask = id++;       /* FIXME how to catch during assembly? */
          o->match = 0;         /* for macros, the insn_isa number */
          o->pinfo = INSN_MACRO;
 #endif
@@ -616,7 +616,7 @@ itbl_disassemble (char *s, unsigned long insn)
       struct itbl_entry *r;
       unsigned long value;
 
-      if (f == e->fields)      /* First operand is preceeded by tab.  */
+      if (f == e->fields)      /* First operand is preceded by tab.  */
        strcat (s, "\t");
       else                     /* ','s separate following operands.  */
        strcat (s, ",");
index 9a0b7c3ccbd0e03f27078f521da9e2ac205399e6..53552d7f31b088484c9ed6ff7a515f5066e88bdf 100644 (file)
@@ -152,7 +152,7 @@ Here is the grammar for the coprocessor table:
            char -> any printable character
            ltr -> ['a'..'z'|'A'..'Z'] 
            dec -> ['0'..'9']*                                       ; value in decimal
-           hex -> '0x'['0'..'9' | 'a'..'f' | 'A'..'F']*        ; value in hexidecimal 
+           hex -> '0x'['0'..'9' | 'a'..'f' | 'A'..'F']*        ; value in hexadecimal 
 
 
 Examples
@@ -239,7 +239,7 @@ was deleted from the original format such that we now count the fields.
 
 ----
 FIXME! should really change lexical analyzer 
-to recognize 'dreg' etc. in context sensative way.
+to recognize 'dreg' etc. in context sensitive way.
 Currently function names or mnemonics may be incorrectly parsed as keywords
 
 FIXME! hex is ambiguous with any digit
index 7510d858959772411036af4a60e9a5f5a237f936..ba1271db86b56b7bf302a14326901283b3de3c04 100644 (file)
@@ -65,7 +65,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
  The function listing_newline remembers the frag associated with the
  newline, and creates a new frag - note that this is wasteful, but not
  a big deal, since listing slows things down a lot anyway.  The
- function also rememebers when the filename changes.
+ function also remembers when the filename changes.
 
  When all the input has finished, and gas has had a chance to settle
  down, the listing is output. This is done by running down the list of
@@ -86,7 +86,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
  LISTING_LHS_WIDTH_SECOND   Number of words for the data on the lhs
                        for the second line
 
- LISTING_LHS_CONT_LINES        Max number of lines to use up for a continutation
+ LISTING_LHS_CONT_LINES        Max number of lines to use up for a continuation
  LISTING_RHS_WIDTH      Number of chars from the input file to print
                         on a line
 */
@@ -127,7 +127,7 @@ typedef struct file_info_struct {
   int                       at_end;
 } file_info_type;
 
/* This structure rememebrs which line from which file goes into which
    frag.  */
 struct list_info_struct {
   /* Frag which this line of source is nearest to.  */
index 77102150737cf3ac9e9d30b53ca70c391bf8990c..0de7d162e0e3b2b45d28f580c50bcd25500a4630 100644 (file)
@@ -35,7 +35,7 @@
    list of formal arguments, and also keeps a hash table which points
    into the list to speed up formal search.  Each formal knows its
    name and its default value.  Each time the macro is expanded, the
-   formals get the actual values attatched to them.  */
+   formals get the actual values attached to them.  */
 
 /* Describe the formal arguments to a macro.  */
 
index 13f10732b5543552af1fa938a5628e45d60ffffc..fbc050f0943eb2e976e0048b942880175e03940a 100644 (file)
@@ -32,7 +32,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
    grow when we do 4361 style flonums.  */
 #define MAXIMUM_NUMBER_OF_CHARS_FOR_FLOAT (16)
 
-/* Routines that read assembler source text to build spagetti in memory.
+/* Routines that read assembler source text to build spaghetti in memory.
    Another group of these functions is in the expr.c module.  */
 
 #include "as.h"
@@ -623,7 +623,7 @@ read_a_source_file (name)
                }
            }
 
-         /* We are at the begining of a line, or similar place.
+         /* We are at the beginning of a line, or similar place.
             We expect a well-formed assembler statement.
             A "symbol-name:" is a statement.
 
@@ -982,7 +982,7 @@ read_a_source_file (name)
                  /* The end of the #APP wasn't in this buffer.  We
                     keep reading in buffers until we find the #NO_APP
                     that goes with this #APP  There is one.  The specs
-                    guarentee it...  */
+                    guarantee it...  */
                  tmp_len = buffer_limit - s;
                  tmp_buf = xmalloc (tmp_len + 1);
                  memcpy (tmp_buf, s, tmp_len);
@@ -3800,7 +3800,7 @@ emit_expr (exp, nbytes)
    them in words, longs, etc. and we'll pack them in target byte order
    for you.
 
-   The rules are: pack least significat bit first, if a field doesn't
+   The rules are: pack least significant bit first, if a field doesn't
    entirely fit, put it in the next unit.  Overflowing the bitfield is
    explicitly *not* even a warning.  The bitwidth should be considered
    a "mask".
@@ -4131,7 +4131,7 @@ hex_float (float_type, bytes)
    by 0d 0f 0g or 0h. After observing the STRANGE way my BSD AS does its
    reading, I decided to be incompatible. This always tries to give you
    rounded bits to the precision of the pseudo-op. Former AS did premature
-   truncatation, restored noisy bits instead of trailing 0s AND gave you
+   truncation, restored noisy bits instead of trailing 0s AND gave you
    a choice of 2 flavours of noise according to which of 2 floating-point
    scanners you directed AS to use.
 
@@ -5344,7 +5344,7 @@ read_print_statistics (file)
    This call avoids macro/conditionals nesting checking, since the contents of
    the line are assumed to replace the contents of a line already scanned.
 
-   An appropriate use of this function would be substition of input lines when
+   An appropriate use of this function would be substitution of input lines when
    called by md_start_line_hook().  The given line is assumed to already be
    properly scrubbed.  */
 
@@ -127,7 +127,7 @@ typedef struct file_info_struct {
 } file_info_type;
 
-/* This structure rememebrs which line from which file goes into which
+/* This structure remembers which line from which file goes into which
    frag.  */
 struct list_info_struct {
index 93d2fcfb04e26d0e8bab45b6f2d53cca3fcb0001..e48246a9207ef2c14f31e7e2266293b7397aa44e 100644 (file)